/* --------------------------------------------------
   Table of Contents
-----------------------------------------------------
:: Shared Styles
:: Site elements
:: Form elements
:: Login, Error Pages
:: Misc
:: Site adjustements
:: Style switcher
:: Media queries
*/


/* -----------------------------------------
   Shared Styles
----------------------------------------- */

	html {overflow-y:scroll}
	body {font:100 13px/1.4 Helvetica, Arial, sans-serif;color:#222;background-color: #eeeeee}
	code,pre{border-radius:3px 3px 3px 3px;font-family:Monaco,Andale Mono,Courier New,monospace;font-size:12px;padding:0 3px 2px}
	code{background-color:#FEE9CC;color:rgba(0,0,0,0.75);padding:1px 3px}
	pre{background-color:#F5F5F5;border:1px solid rgba(0,0,0,0.15);border-radius:3px 3px 3px 3px;display:block;font-size:12px;line-height:18px;white-space:pre-wrap;word-wrap:break-word;margin:0 0 18px;padding:8.5px}
	input:focus, textarea:focus,select:focus {outline: none;}

	/* fix for inputs inline shadow */
	input[type="text"], input[type="email"], input[type="search"], input[type="password"] {
		-webkit-appearance: none;
		-moz-appearance: none;
	}

	.vam{vertical-align:middle}
	.tac{text-align:center}
	.tar{text-align:right}
	.taj{text-align:justify}

	a {color:#21759b}
	a:hover {color:#21759b;text-decoration:underline}
	a:active,a:focus {color: #21759b}
	a.inv {text-decoration:underline}
	a.inv:hover {text-decoration:none}
	.external_link {background: url(../img/external_link.png) no-repeat right center;padding-right:12px}
	a.button {text-decoration:none}
	.clear_form {vertical-align:middle;margin:0 5px}
	*::-moz-selection {background: none repeat scroll 0 0 #367aa9;color: #fff;text-shadow: none}

	/* colors */
		.m_color {color:#fe6001 !important}
		.s_color {color:#8c8c8c !important}
		.w_color {color:#fff}

	/* element separation */
		.sepH_a {margin-bottom:5px}.sepH_b {margin-bottom:10px}.sepH_c {margin-bottom:20px}
		.sepV_a {margin-right:5px}.sepV_b {margin-right:10px}.sepV_c {margin-right:20px}
		.sepH_a_line {padding-bottom:6px;margin-bottom:18px;border-bottom:1px solid #dcdcdc}
		.sepH_no {margin-bottom:0}

	/* no borders for buttons (ie7) */
		button {*border: none !important;*border-color: transparent !important}

	/* webkit extra margin fix*/
		@media screen and (-webkit-min-device-pixel-ratio:0) {
			button {margin: 0px}
		}

	/* text styles */
		.small{font-size:11px}
		.medium {font-size: 13px}
		.large{font-size:17px}

	/* Foundation framework adjustements */
		h1, h2, h3, h4, h5, h6 {font-weight:400}
		small {font-size:11px}
		ul,ol,li {margin-bottom:0}
		ul.pagination {margin-bottom:14px}
		ul.pagination a:hover {text-decoration:none}
		input.input-text:focus, textarea:focus {background: #f3fee7}
		input,textarea,select {font-family:inherit}
		label + input.input-text, label + textarea, label + select, label + div.dropdown, select + div.dropdown {margin-top: -6px}
		.form-field.error label {color: inherit}
		form.custom div.custom.dropdown a:hover {text-decoration:none}
		form.nice div.form-field input,form.nice div.form-field textarea{border-color: #C00000}
		p {line-height: 1.4}
		.row .row {max-width: 100%; min-width: 0}
		.form-field.error input:focus, .form-field.error textarea:focus {background-color: rgba(255,0,0,0.25)}
		.alert-box a.close {padding:3px}
		.alert-box a.close:hover {text-decoration:none}
		ul.pagination li a.current {border-bottom: 2px solid #00A6FC;color: #141414}
		ul.nice li {margin-bottom:12px}
		img {max-width:none\9}
		.alert-box.info {background-color: #058DC7;color: #fff;text-shadow: 0 -1px rgba(0, 0, 0, 0.3)}
		div.alert-box {padding-right:22px}

	/* ------------------------------------------
	CSS3 GITHUB BUTTONS (Nicolas Gallagher)
	Licensed under Unlicense
	http://github.com/necolas/css3-github-buttons
	------------------------------------------ */

	.gh_button {position: relative;overflow: visible;display: inline-block;padding: 0.5em 1em;border: 1px solid #d4d4d4;margin: 0;text-decoration: none;text-shadow: 1px 1px 0 #fff;font:11px/normal sans-serif;color: #333;white-space: nowrap;cursor: pointer;outline: none;background-color: #ececec;background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#f4f4f4), to(#ececec));background-image: -moz-linear-gradient(#f4f4f4, #ececec);background-image: -o-linear-gradient(#f4f4f4, #ececec);background-image: linear-gradient(#f4f4f4, #ececec);-webkit-background-clip: padding;-moz-background-clip: padding;-o-background-clip: padding-box;-webkit-border-radius: 0.2em;-moz-border-radius: 0.2em;border-radius: 0.2em;zoom: 1;*display: inline}
	.gh_button:hover,.gh_button:focus,.gh_button:active,.gh_button.active {border-color: #3072b3;border-bottom-color: #2a65a0;text-decoration: none;text-shadow: -1px -1px 0 rgba(0,0,0,0.3);color: #fff;background-color: #3C8DDE;background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#599bdc), to(#3072b3));background-image: -moz-linear-gradient(#599bdc, #3072b3);background-image: -o-linear-gradient(#599bdc, #3072b3);background-image: linear-gradient(#599bdc, #3072b3)}
	.gh_button:active,.gh_button.active {border-color: #2a65a0;border-bottom-color: #3884CF;background-color: #3072b3;background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#3072b3), to(#599bdc));background-image: -moz-linear-gradient(#3072b3, #599bdc);background-image: -o-linear-gradient(#3072b3, #599bdc);background-image: linear-gradient(#3072b3, #599bdc)}
	.gh_button::-moz-focus-inner {padding: 0;border: 0}
	.gh_button.icon:before {content: "";position: relative;top: 1px;float:left;width: 12px;height: 12px;margin: 0 0.75em 0 -0.25em;background: url(../img/ico/gh-icons.png) 0 99px no-repeat}
	.gh_button.arrowup.icon:before {background-position: 0 0}
	.gh_button.arrowup.icon:hover:before,.gh_button.arrowup.icon:focus:before,.gh_button.arrowup.icon:active:before {background-position: -12px 0}
	.gh_button.arrowdown.icon:before {background-position: 0 -12px}
	.gh_button.arrowdown.icon:hover:before,.gh_button.arrowdown.icon:focus:before,.gh_button.arrowdown.icon:active:before {background-position: -12px -12px}
	.gh_button.arrowleft.icon:before{background-position:0 -24px}
	.gh_button.arrowleft.icon:hover:before,.gh_button.arrowleft.icon:focus:before,.gh_button.arrowleft.icon:active:before{background-position:-12px -24px}
	.gh_button.arrowright.icon:before{float:right;background-position:0 -36px;margin:0 -.25em 0 .5em}
	.gh_button.arrowright.icon:hover:before,.gh_button.arrowright.icon:focus:before,.gh_button.arrowright.icon:active:before{background-position:-12px -36px}
	.gh_button.approve.icon:before{background-position:0 -48px}
	.gh_button.approve.icon:hover:before,.gh_button.approve.icon:focus:before,.gh_button.approve.icon:active:before{background-position:-12px -48px}
	.gh_button.add.icon:before{background-position:0 -288px}
	.gh_button.add.icon:hover:before,.gh_button.add.icon:focus:before,.gh_button.add.icon:active:before{background-position:-12px -288px}
	.gh_button.remove.icon:before{background-position:0 -60px}
	.gh_button.remove.icon:hover:before,.gh_button.remove.icon:focus:before,.gh_button.remove.icon:active:before{background-position:-12px -60px}
	.gh_button.log.icon:before{background-position:0 -72px}
	.gh_button.log.icon:hover:before,.gh_button.log.icon:focus:before,.gh_button.log.icon:active:before{background-position:-12px -72px}
	.gh_button.calendar.icon:before{background-position:0 -84px}
	.gh_button.calendar.icon:hover:before,.gh_button.calendar.icon:focus:before,.gh_button.calendar.icon:active:before{background-position:-12px -84px}
	.gh_button.chat.icon:before{background-position:0 -96px}
	.gh_button.chat.icon:hover:before,.gh_button.chat.icon:focus:before,.gh_button.chat.icon:active:before{background-position:-12px -96px}
	.gh_button.clock.icon:before{background-position:0 -108px}
	.gh_button.clock.icon:hover:before,.gh_button.clock.icon:focus:before,.gh_button.clock.icon:active:before{background-position:-12px -108px}
	.gh_button.settings.icon:before{background-position:0 -120px}
	.gh_button.settings.icon:hover:before,.gh_button.settings.icon:focus:before,.gh_button.settings.icon:active:before{background-position:-12px -120px}
	.gh_button.comment.icon:before{background-position:0 -132px}
	.gh_button.comment.icon:hover:before,.gh_button.comment.icon:focus:before,.gh_button.comment.icon:active:before{background-position:-12px -132px}
	.gh_button.fork.icon:before{background-position:0 -144px}
	.gh_button.fork.icon:hover:before,.gh_button.fork.icon:focus:before,.gh_button.fork.icon:active:before{background-position:-12px -144px}
	.gh_button.like.icon:before{background-position:0 -156px}
	.gh_button.like.icon:hover:before,.gh_button.like.icon:focus:before,.gh_button.like.icon:active:before{background-position:-12px -156px}
	.gh_button.favorite.icon:before{background-position:0 -348px}
	.gh_button.favorite.icon:hover:before,.gh_button.favorite.icon:focus:before,.gh_button.favorite.icon:active:before{background-position:-12px -348px}
	.gh_button.home.icon:before{background-position:0 -168px}
	.gh_button.home.icon:hover:before,.gh_button.home.icon:focus:before,.gh_button.home.icon:active:before{background-position:-12px -168px}
	.gh_button.key.icon:before{background-position:0 -180px}
	.gh_button.key.icon:hover:before,.gh_button.key.icon:focus:before,.gh_button.key.icon:active:before{background-position:-12px -180px}
	.gh_button.lock.icon:before{background-position:0 -192px}
	.gh_button.lock.icon:hover:before,.gh_button.lock.icon:focus:before,.gh_button.lock.icon:active:before{background-position:-12px -192px}
	.gh_button.unlock.icon:before{background-position:0 -204px}
	.gh_button.unlock.icon:hover:before,.gh_button.unlock.icon:focus:before,.gh_button.unlock.icon:active:before{background-position:-12px -204px}
	.gh_button.loop.icon:before{background-position:0 -216px}
	.gh_button.loop.icon:hover:before,.gh_button.loop.icon:focus:before,.gh_button.loop.icon:active:before{background-position:-12px -216px}
	.gh_button.search.icon:before{background-position:0 -228px}
	.gh_button.search.icon:hover:before,.gh_button.search.icon:focus:before,.gh_button.search.icon:active:before{background-position:-12px -228px}
	.gh_button.mail.icon:before{background-position:0 -240px}
	.gh_button.mail.icon:hover:before,.gh_button.mail.icon:focus:before,.gh_button.mail.icon:active:before{background-position:-12px -240px}
	.gh_button.move.icon:before{background-position:0 -252px}
	.gh_button.move.icon:hover:before,.gh_button.move.icon:focus:before,.gh_button.move.icon:active:before{background-position:-12px -252px}
	.gh_button.edit.icon:before{background-position:0 -264px}
	.gh_button.edit.icon:hover:before,.gh_button.edit.icon:focus:before,.gh_button.edit.icon:active:before{background-position:-12px -264px}
	.gh_button.pin.icon:before{background-position:0 -276px}
	.gh_button.pin.icon:hover:before,.gh_button.pin.icon:focus:before,.gh_button.pin.icon:active:before{background-position:-12px -276px}
	.gh_button.reload.icon:before{background-position:0 -300px}
	.gh_button.reload.icon:hover:before,.gh_button.reload.icon:focus:before,.gh_button.reload.icon:active:before{background-position:-12px -300px}
	.gh_button.rss.icon:before{background-position:0 -312px}
	.gh_button.rss.icon:hover:before,.gh_button.rss.icon:focus:before,.gh_button.rss.icon:active:before{background-position:-12px -312px}
	.gh_button.tag.icon:before{background-position:0 -324px}
	.gh_button.tag.icon:hover:before,.gh_button.tag.icon:focus:before,.gh_button.tag.icon:active:before{background-position:-12px -324px}
	.gh_button.trash.icon:before{background-position:0 -336px}
	.gh_button.trash.icon:hover:before,.gh_button.trash.icon:focus:before,.gh_button.trash.icon:active:before{background-position:-12px -336px}
	.gh_button.user.icon:before{background-position:0 -360px}
	.gh_button.user.icon:hover:before,.gh_button.user.icon:focus:before,.gh_button.user.icon:active:before{background-position:-12px -360px}
	.gh_button.primary {font-weight: bold}
	.gh_button.danger {color: #900}
	.gh_button.danger:hover,.gh_button.danger:focus,.gh_button.danger:active {border-color: #b53f3a;border-bottom-color: #a0302a;color: #fff;background-color: #dc5f59;background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#dc5f59), to(#b33630));background-image: -moz-linear-gradient(#dc5f59, #b33630);background-image: -o-linear-gradient(#dc5f59, #b33630);background-image: linear-gradient(#dc5f59, #b33630)}
	.gh_button.danger:active,.gh_button.danger.active {border-color: #a0302a;border-bottom-color: #bf4843;background-color: #b33630;background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#b33630), to(#dc5f59));background-image: -moz-linear-gradient(#b33630, #dc5f59);background-image: -o-linear-gradient(#b33630, #dc5f59);background-image: linear-gradient(#b33630, #dc5f59)}
	.gh_button.pill {-webkit-border-radius: 50em;-moz-border-radius: 50em;border-radius: 50em}
	.gh_button.disable {opacity: 0.5}
	.gh_button.big{font-size:14px}
	.gh_button.small{font-size:11px;padding:.3em .8em}
	.gh_button-group{display:block;list-style:none;overflow:hidden;margin:0;padding:0}
	.gh_button + .gh_button,.gh_button + .gh_button-group,.gh_button-group + .gh_button,.gh_button-group + .gh_button-group{margin-left:15px}
	.gh_button-group li{float:left;margin:0;padding:0}
	.gh_button-group .gh_button{float:left;margin-left:-1px}
	.gh_button-group > .gh_button:not(:first-child):not(:last-child),.gh_button-group li:not(:first-child):not(:last-child) .gh_button{-webkit-border-radius:0;-moz-border-radius:0;border-radius:0}
	.gh_button-group > .gh_button:first-child,.gh_button-group li:first-child .gh_button{margin-left:0;-webkit-border-top-right-radius:0;-webkit-border-bottom-right-radius:0;-moz-border-radius-topright:0;-moz-border-radius-bottomright:0;border-top-right-radius:0;border-bottom-right-radius:0}
	.gh_button-group > .gh_button:last-child,.gh_button-group li:last-child > .gh_button{-webkit-border-top-left-radius:0;-webkit-border-bottom-left-radius:0;-moz-border-radius-topleft:0;-moz-border-radius-bottomleft:0;border-top-left-radius:0;border-bottom-left-radius:0}
	.gh_button-group > .gh_button.pill:only-of-type {-webkit-border-radius: 50em;-moz-border-radius: 50em;border-radius: 50em}
	.gh_button-group.minor-group .gh_button{border:1px solid #d4d4d4;text-shadow:none;background-image:none;background-color:#fff}
	.gh_button-group.minor-group .gh_button:hover,.gh_button-group.minor-group .gh_button:focus{background-color:#599bdc}
	.gh_button-group.minor-group .gh_button:active,.gh_button-group.minor-group .gh_button.active{background-color:#3072b3}
	.gh_button-group.minor-group .gh_button.icon:before{opacity:0.8}
	.gh_button-container .gh_button,.gh_button-container .gh_button-group{vertical-align:top}
	.gh_button.btn-big.icon:before,.gh_button.btn-small.icon:before{top:0}

/* -----------------------------------------
   Site elements
----------------------------------------- */

	/* header */
		header {min-height: 82px;padding-bottom:30px}
		header .head_s_a {padding-top:10px;border-top:5px solid #949494;border-top:5px solid rgba(0,0,0,.4)}
		#logo img {padding:34px 40px 0 16px}
		header .head_s_a .row {position:relative}
		.sw_width {width:15px;height:7px;cursor:pointer;position:absolute;top:5px;right:20px;font-size:10px;background: #949494;background: rgba(0,0,0,.4);padding:3px 4px 4px;-moz-border-radius-topleft: 0px;-moz-border-radius-topright: 0px;-moz-border-radius-bottomright: 4px;-moz-border-radius-bottomleft: 4px;-webkit-border-radius: 0px 0px 4px 4px;border-radius: 0px 0px 4px 4px;-webkit-border-bottom-right-radius: 4px;-webkit-border-bottom-left-radius: 4px;-moz-border-radius-bottomright: 4px;-moz-border-radius-bottomleft: 4px;border-bottom-right-radius: 4px;border-bottom-left-radius: 4px;}
		.sw_width img {background-image: url(../img/sw_width.gif);background-repeat: no-repeat;width:15px;height:7px;display:block}
		.sw_width img.sw_full {background-position:0 0}
		.sw_width img.sw_fixed {background-position:0 -14px}

	/* main nav */
		.ddsmoothmenu{background: #f2f2f2;background: -moz-linear-gradient(top, #ffffff 0%, #f3f3f3 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#ffffff), color-stop(100%,#f3f3f3));background: -webkit-linear-gradient(top, #ffffff 0%,#f3f3f3 100%);background: -o-linear-gradient(top, #ffffff 0%,#f3f3f3 100%);background: -ms-linear-gradient(top, #ffffff 0%,#f3f3f3 100%);background: linear-gradient(top, #ffffff 0%,#f3f3f3 100%);width:100%;border:1px solid #dcdcdc}
		.ddsmoothmenu ul{z-index:990;list-style-type:none;margin:0;padding:0}
		.ddsmoothmenu {-webkit-border-radius: 4px 4px 4px 4px;-moz-border-radius: 4px 4px 4px 4px;-ms-border-radius: 4px 4px 4px 4px;border-radius: 4px 4px 4px 4px}
		.ddsmoothmenu .first_el {-webkit-border-top-left-radius: 4px;-webkit-border-bottom-left-radius: 4px;-moz-border-radius-topleft: 4px;-moz-border-radius-bottomleft: 4px;border-top-left-radius: 4px;border-bottom-left-radius: 4px;}
		.ddsmoothmenu ul li{position:relative;display:inline;float:left}
		.ddsmoothmenu ul li a{text-shadow:1px 1px 0 #fff;font-size:16px;line-height:16px;display:block;color:#2d2b2b;text-decoration:none;padding:8px 12px}
		.ddsmoothmenu > ul li a {border-right:1px dashed #e4e4e4}
		.ddsmoothmenu > ul li:first-child a {border-left:none}
		.ddsmoothmenu ul li a:link,.ddsmoothmenu ul li a:visited{color:#222}
		.ddsmoothmenu ul li ul{position:absolute;left:0;display:none;visibility:hidden;box-shadow: 4px 4px 0 rgba(0,0,0,.1);border:1px solid #dcdcdc}
		.ddsmoothmenu ul li ul li{display:list-item;float:none;}
		.ddsmoothmenu ul li ul li ul{top:0;margin-left:1px;margin-top:-1px}
		.ddsmoothmenu ul li ul li a{min-width:120px;background:#fff;border-top-width:0;border-bottom:1px dotted #ccc;margin:0;padding:5px 12px;white-space: nowrap;font-size:14px}
		.ddsmoothmenu li ul li a {border-left:none;border-right:none}
		.ddsmoothmenu li ul li:last-child a {border:none}
		.downarrowclass{position:absolute;top:15px;right:8px;width:5px;height:3px;background: url(../img/nav_arrow.gif) no-repeat 0 -23px}
		.rightarrowclass{position:absolute;top:12px;right:5px;width:3px;height:5px;background: url(../img/nav_arrow.gif) no-repeat 0 0}
		.ddshadow{position:absolute;left:0;top:0;width:0;height:0;background:silver}
		.toplevelshadow{opacity:0.8}
		.ddsmoothmenu-v ul{list-style-type:none;margin:0;padding:0;border:none}
		.ddsmoothmenu-v ul li{position:relative}
		.ddsmoothmenu-v ul li a{font-size:16px;color:#222;line-height:1;display:block;overflow:auto;text-decoration:none;border-bottom:1px dotted #dcdcdc;border-right:none;padding:5px 12px;background:#fff}
		.ddsmoothmenu-v ul li ul li a {font-size:14px}
		.ddsmoothmenu-v ul li:last-child a {border-bottom:none}
		.ddsmoothmenu-v ul li:last-child ul a {border-bottom:1px dotted #dcdcdc}
		.ddsmoothmenu-v ul li ul{position:absolute;width:170px;top:0;margin:-1px 0 0;font-weight:400;visibility:hidden;box-shadow: 4px 4px 0 rgba(0,0,0,.1);border:1px solid #dcdcdc}
		.ddsmoothmenu ul li a.selected,.ddsmoothmenu ul li a:hover,.ddsmoothmenu-v ul li a.selected,.ddsmoothmenu-v ul li a:hover{background:#eaf4f9;text-decoration:none}
		#smoothmenu_h {position:relative;z-index:990}
		#smoothmenu_v {position:relative;z-index:980;background:#fff;border:1px solid #dcdcdc;padding:8px}
		#smoothmenu_v ul>li>a {border-right:none}
		.sticky_nav {z-index: 880;left:0 !important;width:100% !important;-webkit-border-radius: 0 0 0 0;-moz-border-radius: 0 0 0 0;-ms-border-radius: 0 0 0 0;border-radius: 0 0 0 0}
		.sticky_nav_center {z-index: 880;-webkit-border-radius: 0 0 0 0;-moz-border-radius: 0 0 0 0;-ms-border-radius: 0 0 0 0;border-radius: 0 0 0 0}
        .tinynav { display: none }

	/* breadcrumbs */
		#breadcrumbs {position:relative;top:-1px;margin:0 10px;list-style:none;font-size:11px;background:#fff;border:1px solid #dcdcdc;-moz-border-radius-topleft: 0px;-moz-border-radius-topright: 0px;-moz-border-radius-bottomright: 4px;-moz-border-radius-bottomleft: 4px;-webkit-border-radius: 0px 0px 4px 4px;border-radius: 0px 0px 4px 4px}
		#breadcrumbs li {display:block;float:left;color:#c1c1c1;padding:3px 0}
		#breadcrumbs li:after {content:"/"}
		#breadcrumbs li a {margin:0 6px}
		#breadcrumbs li span {margin-left:6px;color:#999}
		#breadcrumbs li:first-child {color:#999;padding:3px 4px 3px 10px}
		#breadcrumbs li:first-child:after,#breadcrumbs li:last-child:after {content:""}

	/* search top*/
		#search_box {position:relative}
		#search_box input[type="text"] {font-size:13px;margin-top:27px;background: url(../img/mag_glass.png) no-repeat 10px center #fff;border: 1px solid #d1d1d1;color: #888;width: 100px;padding: 6px 15px 6px 35px;-webkit-border-radius: 4px;-moz-border-radius: 4px;border-radius: 4px;width:120px;box-shadow: 2px 2px 0px rgba(0,0,0,.08)}
		#search_box input[type="text"]:focus {color:#222}

	/* autocomplete */
		.ac_results {padding: 0px;background-color: Window;overflow-x: hidden;box-shadow:0 5px 12px #ccc;z-index:9999}
		.ac_results ul {width: 100%;list-style-position: outside;list-style: none;padding: 0;margin: 0;overflow:hidden !important}
		.ac_results li {margin: 0px;padding: 2px 5px;cursor: pointer;display: block;width: 100%;font-size: 12px;overflow: hidden}
		.ac_results strong {color:#fe6001}
		.ac_loading {background : url('../lib/autocomplete/css/indicator.gif') right center no-repeat}
		.ac_over {background-color: Highlight;color: HighlightText}
		.ac_over strong {color:#fff}
		.search_results {padding:10px}
		.search_pop {max-width:600px}
		.search_results mark {background: #f5f2a6;padding:0 4px;-webkit-border-radius: 4px;-moz-border-radius: 4px;border-radius: 4px}

	/* user box */
		.user_box {float:right;background:#fff;border:1px solid #dcdcdc;padding:10px;line-height:1.2;font-size:11px;margin-top:10px}
		.user_box .user_avatar {float:left;padding:6px 0 4px 6px}
		.user_box .user_info {padding:4px 0 4px 10px;float:left}
		.user_box .user_info p {font-size:11px}
		.user_box a {font-size:10px}
		.user_box a.sep {border-right:1px solid #e8e8e8;margin-right:3px;padding-right:6px}
		.user_box .user_sep {border-left:1px dashed #dcdcdc;margin-left:14px}

	/* header notifications */
		.ntf_bar {float:left;padding:10px 0 2px 22px;height:32px}
		.ntf_item {position:relative;margin-right:12px;height:32px;vertical-align:middle;width:34px;background-repeat:no-repeat;background-position: 0 50%}
		.ntf_item:hover {text-decoration:none}
		.ntf_bar .ntf_tip {position:absolute;top:-8px;left:100%;margin-left:-18px}
		.ntf_tip {display:block;height:17px;overflow:hidden;padding-left:10px}
		.ntf_tip span {display:block;padding-top:1px;height:16px;line-height:10px;color:#fff;font-size:10px;float:left;font-weight:700;padding-right:10px}
		.ntf_tip_red {background: url(../img/ntf_tip.png) no-repeat 0 -34px}
		.ntf_tip_red span {background: url(../img/ntf_tip.png) no-repeat right -51px}
		.ntf_tip_blue {background: url(../img/ntf_tip.png) no-repeat 0 0}
		.ntf_tip_blue span {background: url(../img/ntf_tip.png) no-repeat right -17px}

	/* widget box */
		.box_c,.box_s,.box_s_reg {margin-bottom:30px}
		.box_c_heading {height:30px;border:1px solid #dcdcdc;font-size:16px;line-height:30px;position:relative}
		.box_c_heading .ff_icon {color:#bdbdbd;font-size:20px}
		.box_c_heading .box_c_ico {width:36px;border-right:1px solid #dcdcdc;box-shadow: 1px 0 0 rgba(255,255,255,.5);background: transparent;background: rgba(0, 0, 0, .2);float:left;text-align:center;line-height:34px;height:30px;overflow:hidden}
		.box_c_heading p {padding-left:12px !important;float:left;margin-bottom:0 !important;line-height:28px !important;font-size:16px !important}
		.box_c_heading a.right {line-height:26px}
		.box_c_heading .gh_button-group {margin:4px 12px 0 0}
		.box_c_heading .gh_button-group a {color:#333 !important}
		.box_c_heading .gh_button-group a:hover {color:#fff !important}
		.box_c_content {padding:12px;border-width:0 1px 1px;border-style:solid;border-color: #dcdcdc;background:#fff}
		.cntn_noP {padding:0}
		.bAct_hide,.bAct_toggle {background: url(../img/bAct_bg.png) no-repeat 0 0;display:block;float:right;height:18px;width:18px;overflow:hidden;margin:7px 5px 0 0}
		.bAct_hide img,.bAct_toggle	img {display:block;cursor:pointer;background-image: url(../img/bAct_bg.png);background-repeat: no-repeat;height:18px;width:18px}
		.bAct_x {background-position: 0 -18px}
		.bAct_minus {background-position: 0 -36px}
		.bAct_plus {background-position: 0 -54px}

	/* simple box */
		.box_s {padding:8px;border:1px solid #dcdcdc;background:#fff}
		.box_s_reg {padding:14px;border:1px solid #dcdcdc;background:#fff;font-size: 12px}

	/* inner blocks */
		.inner_block {padding:8px;background:#fafafa;border:1px solid #f1f1f1}
		.inner_heading {font-size:12px;padding:0 0 6px 2px;border-bottom:1px solid #e8e8e8}
		.inner_content {margin:0 12px 12px}

	/* tables */
		.chb_col {width:16px !important;vertical-align:middle;text-align:center}

	/* tables mobile */
		.table-menu{font-size:13px;padding:10px 0}
		.table-menu li{padding:4px 0}
		.enhanced th,.enhanced td,.table-menu-hidden {display:none}
		.legacy-ie .enhanced th.essential,.legacy-ie .enhanced td.essential{display:inline}
		.enhanced th.essential,.enhanced td.essential{display:table-cell}

	/* tooltips */
		.tooltip {display:none;font-size:10px;padding:3px 6px;color:#fff;background:#000;background:rgba(0, 0, 0, 0.7);text-align:center;-webkit-border-radius: 4px;-moz-border-radius: 4px;border-radius: 4px}
		.tooltip:after {content: "";position: absolute}
		.tooltip.t_t:after {top: 100%;left: 50%;margin-left:-4px;border-width:4px 4px 0;border-style: solid;border-color: #000 transparent transparent;border-color: rgba(0, 0, 0, 0.7) transparent transparent}
		.tooltip.t_b:after {bottom: 100%;left: 50%;margin-left:-4px;border-width:0 4px 4px;border-style: solid;border-color: transparent transparent #000;border-color: transparent transparent rgba(0, 0, 0, 0.7)}
		.tooltip.t_l:after {top: 50%;left: 100%;margin-top:-3px;border-width:3px 0 3px 5px;border-style: solid;border-color: transparent transparent transparent #000;border-color: transparent transparent transparent rgba(0, 0, 0, 0.7)}
		.tooltip.t_r:after {top: 50%;right: 100%;margin-top:-3px;border-width:3px 5px 3px 0;border-style: solid;border-color: transparent  #000 transparent transparent;border-color: transparent  rgba(0, 0, 0, 0.7) transparent transparent}

	/* tabs */
		.tabs li {display:block;float:left;height:30px;font-family: Helvetica, Arial, sans-serif;}
		.tabs li a{display:block;line-height:31px;padding:0 10px;border-width:0 1px;border-style:solid;border-color:transparent;font-size:12px;position:relative}
		.tabs li a:hover {text-decoration:none}
		.tabs li:last-child a {border-right:none}
		.tabs li a.current {background:#fff;border-color:#dcdcdc;color:#222}

	/* sticky panel */
		div.sticky-queue p {margin:0}
		div.sticky-queue{z-index:10001;position:fixed;background:#fff;border:1px solid #999;box-shadow:0 0 5px #bbb;-moz-box-shadow:0 0 5px #bbb;-webkit-box-shadow:0 0 5px #bbb;width:240px;font-size:11px}
		div.sticky-note{padding-right:20px}
		div.sticky{font-size:12px;color:#555;display:none;position:relative;padding:16px 10px 10px}
		img.sticky-close{position:absolute;top:10px;right:10px;height:14px;width:14px;cursor:pointer;background: url(../img/close.png) no-repeat 0 0}
		.top-right,.top-left{top:-2px;border-bottom-right-radius:6px;border-bottom-left-radius:6px;-moz-border-radius-bottomright:6px;-moz-border-radius-bottomleft:6px;-webkit-border-bottom-right-radius:6px;-webkit-border-bottom-left-radius:6px}
		.bottom-right,.bottom-left{bottom:-2px;border-top-right-radius:6px;border-top-left-radius:6px;-moz-border-radius-topright:6px;-moz-border-radius-topleft:6px;-webkit-border-top-right-radius:6px;-webkit-border-top-left-radius:6px}
		.border-top-right,.border-top-left{border-top:1px solid #999}
		.border-bottom-right,.border-bottom-left{border-bottom:1px solid #999}
		.top-right,.bottom-right{right:20px}
		.top-left,.bottom-left{left:20px}
		div.sticky-queue .sticky-title {font-size:11px;text-transform:uppercase;border-bottom:1px solid #dcdcdc;margin-bottom:8px;padding:0 0 4px 4px}
		div.sticky-queue ul {margin:0 0 8px;padding:0}
		div.sticky-queue li {list-style:none;display:block;line-height:1.2;padding:0 4px 4px;margin-bottom:4px;border-bottom:1px dashed #dcdcdc}

	/* top bar nottifications */
		#showMessage {display:none;color:#fff}
		#showMessage.success {background-color:#7fae00}
		#showMessage.fail {background-color:#c00000}
		#showMessage.alert {background-color:#f68b01}
		#showMessage.info {background-color:#00a6fc}
		#showMessage a {color:#fff}
		.showMsg_inner {padding:10px 0}
		.showMsg_inner ul {padding:0 10px}
		.showMsg_nav {float:right;padding-right:14px;font-size:small}
		.showMsg_list {margin: 0;padding:0}
		.showMsg_list li {list-style:none}


	/* scrollable */
		.v_scroller {background:#f5f5f5;padding:0}
		.v_navi {list-style:none;width:16%;float:left;margin:0;padding:10px 0;position:relative;left:1px;z-index:10}
		.v_navi li {font-size:13px;padding:8px;margin-bottom:2px;cursor:pointer;border-width:1px 0;border-style:solid;border-color:transparent;color:#a0a0a0}
		.v_navi li.current {border-color:#dcdcdc;background:#fff;color:#222}
		.v_scrollable {background:#fff;position:relative;overflow:hidden;border-left:1px solid #dcdcdc;margin-left:10px;min-height:140px}
		.v_scrollable .items {position:absolute;height:20000em}
		.v_scrollable .page {padding:10px 20px}
		.h_scrollable {position:relative;overflow:hidden;width:100%;min-height:200px}
		.h_scrollable .items {width:20000em;position:absolute}
		.h_navi li {cursor:pointer}
		.tab_pane {overflow:hidden}

	/* accordion */
		.accordion {margin:0}
		.accordion li {list-style:none}
		.accordion .outer {border:1px solid #dcdcdc; border-width:0 1px 1px; background: #fff}
		.accordion .inner {margin-bottom:0; padding:10px 20px 15px}
		.accordion .inner .inner {padding:10px}
		.accordion .inner form {margin-bottom: 0}
		.accordion .h {margin: 0}
		.accordion .h a {color:#222;overflow:hidden;position:relative;cursor:pointer;font:700 12px/30px Helvetca, Arial, sans-serif;border:1px solid #dcdcdc;padding:0 12px;margin:10px 0 0;background: #fcfcfc;background: -moz-linear-gradient(top, #fcfcfc 0%, #efefef 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#fcfcfc), color-stop(100%,#efefef));background: -webkit-linear-gradient(top, #fcfcfc 0%,#efefef 100%);background: -o-linear-gradient(top, #fcfcfc 0%,#efefef 100%);background: -ms-linear-gradient(top, #fcfcfc 0%,#efefef 100%);background: linear-gradient(top, #fcfcfc 0%,#efefef 100%);filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#fcfcfc', endColorstr='#efefef',GradientType=0 )}
		.accordion .h a	img {background: url(../img/down.gif) no-repeat 0 0;height:6px;width:14px;position:absolute;right:-14px;top:50%;margin-top:-3px;-webkit-transition:  all 0.2s ease-in-out;-moz-transition:  all 0.2s ease-in-out;-o-transition:  all 0.2s ease-in-out;-ms-transition:  all 0.2s ease-in-out;transition:  all 0.2s ease-in-out}
		.accordion .h a:hover {text-decoration:none}
		.accordion .h a:hover img {right:10px}
		.accordion .h a.open img {-webkit-transform:rotate(180deg);-moz-transform:rotate(180deg);transform:rotate(180deg);right:14px}
		.accordion p {font-size:12px;margin:0}

	/* small labels */
		.lbl {padding:2px 6px;font-size:10px;color:#fff;position:relative;top:-1px;vertical-align:middle}
		.ok_bg {background:#70a415}
		.alert_bg {background:#F5AA1A}
		.info_bg {background:#058dc7}
		.error_bg {background:#C62626}
		.neutral_bg {background:#929494}

	/* content list */
		.content_list {list-style:none;font-size:12px}
		.content_list li {color:#d1d1d1;padding:0 4px 8px;margin-bottom:8px;border-bottom:1px solid #f1f1f1;line-height:1.1}
		.content_list li:last-child {border:none}
		.content_list p {margin-bottom:0;color:#222}

	/* slide to top */
		#toTop{display:none;text-decoration:none;position:fixed;bottom:10px;right:10px;overflow:hidden;width:32px;height:32px;border:none;text-indent:-999px;background:url(../img/ui.totop.png) no-repeat left top}
		#toTopHover{background:url(../img/ui.totop.png) no-repeat left -32px;width:32px;height:32px;display:block;overflow:hidden;float:left;opacity:0;-moz-opacity:0;filter:alpha(opacity=0)}
		#toTop:active,#toTop:focus{outline:none}

	/* footer */
		#footer {font-size:11px;margin-top:20px;height:30px}

/* -----------------------------------------
   Form elements
----------------------------------------- */

	.form_a {background:#fafafa;padding:0}
	.form_a form {padding:18px 0 0}
	.form_a small {display:block}
	.formRow {padding:9px 18px;border-bottom:1px solid #ededed}
	.formRow:last-child {border:none}
	input.input-text, textarea, select {border-width:1px;border-style:solid;border-color:#a9a9a9 #dcdcdc #dcdcdc #a9a9a9}
	select {max-width:96%;padding:3px 2px;background: #fff}
	textarea {height:100px}
	textarea.auto_expand {height:auto}
	.form_content {border-left:1px solid #e0e0e0}
	.form_legend {padding:0 12px}
	.form_legend p {font-size:11px;margin-bottom:0}
	.form_content .formRow:first-child {border-top:1px solid #e0e0e0}
	.form_content .formRow:last-child {border-bottom:1px solid #e0e0e0}
	.form_content .formRow {background:#fafafa;border-color:#e0e0e0;border-bottom:none}
	label.error {font-weight:700;font-size:12px;clear:both;position:relative;margin-top:-6px;color:#c00000 !important;float:none;display:block}

	/* timepicker */
		.ui-timepicker-div .ui-widget-header { margin-bottom: 8px; }
		.ui-timepicker-div dl { text-align: left; }
		.ui-timepicker-div dl dt { height: 25px; margin-bottom: -25px; padding-left:5px }
		.ui-timepicker-div dl dd { margin: 0 10px 22px 65px; }
		.ui-timepicker-div dl dd div {margin-top:5px}
		.ui-timepicker-div td { font-size: 90%; }
		.ui-tpicker-grid-label { background: none; border: none; margin: 0; padding: 0; }

	/* animated progresbar */
		.pbar .ui-progressbar-value {display:block !important}
		.pbar {overflow: hidden}
		.percent,.elapsed {position:relative;text-align: right; font-size: 12px}

	/* jquery UI custom */
		.ui-widget-header a {font-size:12px;line-height:13px}
		.ui-tabs {width:auto;overflow:hidden}
		.ui-scrollable-tabs {border:none;background: none;position:relative}
		.ui-scrollable-tabs .ui-tabs-nav {width:10000px;padding:1px 0 0 1px;border-left:none;border-right:none;padding-top:1px;position:relative}
		.ui-scrollable-tabs .ui-tabs-nav-arrows{left:0;position:absolute;right:0;top:2px;padding:0}
		:first-child+html .ui-scrollable-tabs .ui-tabs-nav-arrows{z-index:1}
		.ui-scrollable-tabs .ui-tabs .ui-tabs-nav li{margin:0 1px}
		.ui-tabs-nav li .ui-tabs-close{float:left;margin-top:8px;margin-right:4px;border:none;cursor:pointer}
		.ui-scrollable-tabs .ui-tabs-nav-arrows .ui-tabs-arrow-next{float:right}
		.ui-scrollable-tabs .ui-tabs-nav-arrows .ui-tabs-arrow-previous{float:left}
		.ui-scrollable-tabs .ui-tabs-nav-arrows li{list-style:none;position:relative;cursor:pointer;display:none;z-index:1;margin:0;padding:0}
		.ui-scrollable-tabs .ui-tabs-nav-arrows li a{display:block;padding:5px 0 4px}
		.ui-datepicker {z-index:10 !important}

	/* spinner */
		label + .ui-spinner {margin-top:-6px}
		.ui-spinner button {height:14px;position:absolute;background:none;border:none;width:18px;padding:0;background: url(../img/spinner_arrows.gif) no-repeat 0 -100px;cursor:pointer}
		.ui-spinner .ui-spinner-up {top:0;right:0;background-position:0 0}
		.ui-spinner .ui-spinner-down {top:14px;right:0;background-position:0 -14px}
		.ui-spinner .ui-spinner-up:hover {background-position:-18px 0}
		.ui-spinner .ui-spinner-down:hover {background-position:-18px -14px}
		.ui-spinner {
			position:relative;
			background: url("../foundation/images/misc/input-bg.png") 0 0 #fff;
			font-size: 13px;
			outline: none !important;
			padding: 0 24px 0 8px;
			border: 1px solid #BBBBBB;
			border-radius: 2px 2px 2px 2px;
			font-family: inherit;
			overflow: hidden;
			height: 28px;
			line-height:28px
		}
		.ui-spinner .ui-spinner-box {background: none;border: none !important}

/* -----------------------------------------
   Login, Error pages
----------------------------------------- */

	/* login page */
		.login_box{position:relative;background:#fff;-webkit-box-shadow:0 1px 4px rgba(0,0,0,0.3), 0 0 40px rgba(0,0,0,0.1) inset;-moz-box-shadow:0 1px 4px rgba(0,0,0,0.3), 0 0 40px rgba(0,0,0,0.1) inset;box-shadow:0 1px 4px rgba(0,0,0,0.3), 0 0 40px rgba(0,0,0,0.1) inset;margin:80px 10px 4em}
		.login_box:before,.login_box:after{content:"";position:absolute;z-index:-2}
		.login_box:before{-webkit-box-shadow:0 0 15px rgba(0,0,0,0.4);-moz-box-shadow:0 0 15px rgba(0,0,0,0.4);box-shadow:0 0 15px rgba(0,0,0,0.4);top:50%;bottom:0;left:10px;right:10px;-moz-border-radius:100px / 10px;border-radius:100px / 10px}
		.lb_content{position:relative;background:#fff;min-height:200px;padding:14px 14px 30px}
		.login_logo {position:absolute;top:-34px;left:14px}
        .lb_ribbon{color:#fff;position:relative;font-size:14px;float:left;clear:both;left:-20px;margin-bottom:30px;text-shadow:1px 1px 0 rgba(0,0,0,.2);-moz-box-shadow:2px 2px 0 rgba(0,0,0,0.1);-webkit-box-shadow:2px 2px 0 rgba(0,0,0,0.1);-o-box-shadow:2px 2px 0 rgba(0,0,0,0.1);box-shadow:2px 2px 0 rgba(0,0,0,0.1);padding:10px 24px}
		.lb_ribbon:before{content:" ";background-image:url(../img/ribbon.png);background-repeat:no-repeat;display:block;width:10px;height:10px;position:absolute;bottom:0;left:0;margin-bottom:-10px;z-index:-1}
		.lb_ribbon.lb_blue {background:#2b8cbe}
		.lb_ribbon:before{background-position: 0 0}
		.lb_ribbon.lb_dgray {background:#404040}
		.lb_dgray:before{background-position: 0 -10px}
		.lb_ribbon.lb_red {background:#ca0020}
		.lb_red:before{background-position: 0 -20px}
		.sl_link {display:block;margin:12px 24px 0 0}
		.m_cont {overflow:hidden}
		.l_pane {background:#fff}

	/* error pages */
		.error_box{margin-top:20%;position:relative;-webkit-box-shadow:0 1px 4px rgba(0,0,0,0.2), 0 0 40px rgba(0,0,0,0.1) inset;-moz-box-shadow:0 1px 4px rgba(0,0,0,0.2), 0 0 40px rgba(0,0,0,0.1) inset;box-shadow:0 1px 4px rgba(0,0,0,0.2), 0 0 40px rgba(0,0,0,0.1) inset}
		.error_box:before,.login_box:after{content:"";position:absolute;z-index:-2}
		.error_box:before{-webkit-box-shadow:0 0 15px rgba(0,0,0,0.4);-moz-box-shadow:0 0 15px rgba(0,0,0,0.4);box-shadow:0 0 15px rgba(0,0,0,0.4);top:50%;bottom:0;left:10px;right:10px;-moz-border-radius:100px / 10px;border-radius:100px / 10px}
		.error_panel {background: #fff url(../img/ico/alert64.png) no-repeat 30px center;padding:50px 30px 50px 120px}
		.error_link {position:absolute;bottom:10px;right:14px;font-size:11px}
		.error_box p {line-height:1.5;margin-bottom:8px}


/* -----------------------------------------
   Misc
----------------------------------------- */

	/* image styles (figure,figcaption) */
		.picture { background-color: #F9F9F9;border: 1px solid #ccc; padding: 3px;font:100 11px/1.3 Arial, sans-serif;display:block}
		.picture a:hover {text-decoration:none}
		.picture img {border: 1px solid #ccc;vertical-align:middle; margin-bottom: 3px;display: block}
		.picture.right {margin: 0.2em 0 0.2em 0.8em; float:right}
		.picture.left {margin: 0.2em 0.8em 0.2em 0; float:left}
		.picture figcaption {max-width:92px;color:#777 !important}

	/* overview list */
		.overview_list {list-style:none}
		.overview_list a {position:relative;color:#222;display:block;line-height:18px;font-size:13px;padding:8px 8px 8px 80px;overflow:hidden;border:1px solid #dcdcdc;margin-bottom:10px;-webkit-border-radius: 6px 6px 6px 6px;-moz-border-radius: 6px 6px 6px 6px;border-radius: 6px 6px 6px 6px;background: #f7f7f7}
		.overview_list a img {position:absolute;top:0;left:0;height:52px;width:60px;background-color:#fff;background-repeat:no-repeat;background-position:center center;border-right:1px solid #e4e4e4;box-shadow:1px 0 0 #fff;-webkit-border-top-left-radius: 6px;-webkit-border-bottom-left-radius: 6px;-moz-border-radius-topleft: 6px;-moz-border-radius-bottomleft: 6px;border-top-left-radius: 6px;border-bottom-left-radius: 6px}
		.overview_list .ov_nb {color:#A80000;font-size:14px;display:block;font-weight:700}
		.overview_list .ov_text {font-size:12px}
        .overview_list a:hover {text-decoration:none;border-color:#cbcbcb;box-shadow: 0 0 5px #d4d4d4}

	/* letter navigation list */
		.ln-letters { overflow:hidden;padding:4px 0 16px}
		.ln-letters a {-webkit-border-radius:4px;-moz-border-radius:4px;-ms-border-radius:4px;border-radius:4px;font-size:12px;min-width:12px;text-align:center;display:block; float:left; padding:2px 6px;margin:2px 4px 2px 0;border:1px solid #dcdcdc;text-decoration:none;background: #fff;background: -moz-linear-gradient(top, #fff 0%, #eee 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#fff), color-stop(100%,#eee));background: -webkit-linear-gradient(top, #fff 0%,#eee 100%);background: -o-linear-gradient(top, #fff 0%,#eee 100%);background: -ms-linear-gradient(top, #fff 0%,#eee 100%);background: linear-gradient(top, #fff 0%,#eee 100%)}
		.ln-letters a:hover,.ln-letters a.ln-selected {background: #E5E5E5}
		.ln-letters a.ln-disabled {color:#BFBFBF;border-color:#ececec;background:#F9F9F9}

	/* pricing table */
		.pricing_table {padding:10px;text-align:center}
		.pricing_table .pricing_panel {width:28%;border:1px solid #ddd;background:#f9f9f9;padding:10px;margin:14px 0 6px;vertical-align:top}
		.pricing_table .pricing_promoted {width:30%;border:4px solid #2179b8;margin:0 -5px;vertical-align:top;background:#fff;padding:21px 10px 20px;box-shadow: 0 2px 12px rgba(0, 0, 0, 0.25);position:relative}
		.pricing_table .header {border-bottom:1px solid #d6d6d6;margin-bottom:14px;padding-bottom:10px}
		.pricing_table h1,.pricing_table h2,.pricing_table h3,.pricing_table h4 {margin-bottom:4px}
		.pricing_table .header p {font-size:13px;color:#333;margin-bottom:0;color:#6b6b6b}
		.pricing_table .pricing_row {border-bottom:1px dashed #dcdcdc;padding:5px 0;font-size:13px}
		.pricing_table .pricing_row strong {color:#ff5500}
		.pricing_action {padding:18px 0 10px}
		.pricing_bottom {font-size:12px;font-style:italic;padding:20px 0 0;margin:0}

	/* gallery list */
		.gallery_list {margin:0;padding:0;position:relative;list-style:none;width:447px}
		.gallery_list li {float:left;position:relative;overflow:hidden;text-align:center}
		.gallery_list span.img_overlay {background:#000 url(../img/mag_glass.png) no-repeat center center;background: rgba(0,0,0,.6) url(../img/mag_glass.png) no-repeat center center;border-radius: 20px 20px 20px 20px;color: #ddd;cursor: pointer;display: block;font-size: 24px;height: 40px;left: 50%;line-height: 40px;margin-left: -20px;margin-top: -20px;position: absolute;text-align: center;top: 50%;width: 40px;z-index: 1000;opacity:0}
		.gallery_list li img {display:block;width:96%;padding:2%;border:1px solid #ccc}
		.img_wrapper {display:block;padding:4px}
		.img_actions {position:absolute;bottom:0;left:0;width:100%;height:100%}
		.slide_info {text-align:left;z-index:1002;position:absolute;top:6%;left:6%;background:#000;background: rgba(0,0,0,.6);width:73%;height:72%;padding:8%;color:#fff;font-size:11px}
		.slide_info span {display:block;padding:2px 0}
		.slide_info a {color:#7CBDE3;margin-right:8px}
		.slide_info .slide_close {position:absolute;top:-4px;right:4px;color:#fff;cursor:pointer}
		.gal_scrollable {height:332px}

	/* sidebar */
		#sidebar {float:left;width:220px;display:none}
		#mainCol {position:relative}
		.divider {cursor:pointer;position:absolute;top:0;left:-18px;width:5px;text-indent:-9999px;background:#dcdcdc;background:#fff;background:rgba(255,255,255,.4);border:1px solid #dcdcdc;-webkit-transition: all .4s ease-in-out;-moz-transition: all .4s ease-in-out;-o-transition: all .4s ease-in-out;-ms-transition: all .4s ease-in-out;transition: all .4s ease-in-out;-webkit-border-radius: 4px 4px 4px 4px;-moz-border-radius: 4px 4px 4px 4px;-ms-border-radius: 4px 4px 4px 4px;border-radius: 4px 4px 4px 4px}
		.divider:before {content:"";display:block;background: url(../img/divider_img.png) no-repeat 0 0;height:17px;width:17px;position:absolute;top:40px;left:-6px}
		.divider.colapsed:before {background-position:0 -17px}
		.divider:hover {background:#fff}
		.use-sidebar #sidebar {display:block}
		.use-sidebar #mainCol {margin-left:250px}

	/* sparklines */
		.sprkList li {padding:8px 10px 14px;border-bottom:1px solid #e8e8e8;margin-bottom:8px;line-height:1}
		.sprkList li:last-child {border:none;margin:0}
		.sprkList p {margin-bottom:0}
		.sparkItem {width:80px;height:30px;padding:2px;text-align:center}

	/* help/Faq */
		.st-accordion{width:100%;margin:0 auto}
		.st-accordion .top_H {height:auto;border-bottom:1px solid #dcdcdc;border-top:1px solid #fff;overflow:hidden}
		.st-accordion .top_H:first-child{border-top:none}
		.st-accordion .top_H:last-child{border-bottom: none}
		.st-accordion .top_Ha{padding:10px 40px 10px 10px;font-size:22px;display:block;position:relative;outline:none;color:#21759b;overflow:hidden}
		.st-accordion .top_Ha span.st-arrow{visiblity:hidden;background:transparent url(../img/down.gif) no-repeat center center;text-indent:-9000px;width:26px;height:14px;position:absolute;top:50%;right:-26px;margin-top:-7px;opacity:0;-webkit-transition:all .2s ease-in-out;-moz-transition:all .2s ease-in-out;-o-transition:all .2s ease-in-out;-ms-transition:all .2s ease-in-out;transition:all .2s ease-in-out}
		.st-accordion .top_Ha:hover {text-decoration: none}
		.st-accordion .top_Ha:hover span.st-arrow{opacity:1;right:10px}
		.st-accordion .st-open .top_Ha span.st-arrow{-webkit-transform:rotate(180deg);-moz-transform:rotate(180deg);transform:rotate(180deg);right:10px;opacity:1}
		.st-accordion .top_Ha:hover,.st-accordion .st-open .top_Ha{color:#000}
		.st-content{padding:5px 10px 20px}
		.st-content p{font-size:14px;line-height:22px}
		#st-documentation small {color:#999}

	/* RSS/Atom feeds */
		#divRss {font-size:12px;overflow:hidden}
		.ItemTitle{font-weight:700;font-size:15px;line-height:17px;margin-bottom:5px !important;margin-top:8px;padding:8px 0 0;border-top:1px solid #dcdcdc}
		.ItemTitle:first-child {border:none;margin:0;padding:0}
		.ItemTitle a{text-decoration:none}
		.ItemTitle a:hover{ text-decoration:underline }
		.ItemContent{padding:2px 2px 0}
		.ItemDate{font-size:11px;color:#aaa}

	/* wizard */
		.stepy-titles {overflow:hidden;padding:0 10px}
		.stepy-titles li {margin:0 4px 12px 0;cursor:pointer;position:relative;line-height:1;float:left;padding:7px 14px 5px 40px;border:1px solid #dcdcdc;height:30px;-webkit-border-radius: 4px;-moz-border-radius: 4px;-ms-border-radius: 4px;border-radius: 4px;-webkit-box-shadow: inset 0px 0px 0px 1px #fff;-moz-box-shadow: inset 0px 0px 0px 1px #fff;box-shadow: inset 0px 0px 0px 1px #fff; }
		.stepy-titles li.error-image {background-image: url(../lib/stepy/img/error_img.png);background-repeat: no-repeat;background-position: right 0}
		.stepy-titles div {font-size:13px;font-weight:700}
		.stepy-titles span {font-size:11px;color:#999}
		span.stepNb	{font-size: 34px;position:absolute;left:10px;top:4px;color:#bbb;font-weight:700}
		.stepy-titles .current-step {background: #e4f0f8;border-color:#aed2ea}
		.stepy-titles .current-step span.stepNb {color:#81a1b5}
		.stepy-wizzard fieldset {border:none;margin:0;padding:0 10px}
		.stepy-wizzard fieldset > p {margin:0 0 0 18px;padding:10px 0 0}
		.stepy-wizzard legend {display:none}

	/* row display */
		.row.display { background: #f4f4f4; margin-bottom: 10px; border-radius: 3px; -webkit-border-radius: 3px; -moz-border-radius: 3px; }
		.row.display .column, .row.display .columns { background: #e7e7e7; font-size: 11px; text-indent: 3px; padding-top: 6px; padding-bottom: 6px; border-radius: 3px; -webkit-border-radius: 3px; -moz-border-radius: 3px; }

	/* documentation */
		.bc_show {height:60px;width:60px;margin:0 0 32px 0;border:1px solid #dcdcdc;-webkit-border-radius: 8px;-moz-border-radius: 8px;-ms-border-radius: 8px;border-radius: 8px;position:relative}
		.bc_show span {position:absolute;bottom:-22px;width:60px;text-align:center;height:18px;line-height:18px;font-size:11px;color:#222}

	/* plugins adjustement */
		.table_prev {background:  url(../img/table_arrows.gif) no-repeat 2px center;width:9px;height:25px;display:block}
		.table_next {background:  url(../img/table_arrows.gif) no-repeat -9px center;width:9px;height:25px;display:block}
		.fc-header-title h2 {font-size: 18px}
		.dataTables_scrollHeadInner {margin-top:12px}
		.dataTables_scrollHeadInner table {margin-bottom:0;top:1px}
		.dataTables_scrollBody {margin-bottom:12px}
		.dataTables_scrollBody table {margin-bottom:0;top:0}
		td.details > table {width:100%}

	/* search page */
		.search_page .search_heading {font-size:14px;color:#2e2e2e;background:#efefef;padding:4px 6px;-webkit-border-radius: 4px;-moz-border-radius: 4px;-ms-border-radius: 4px;border-radius: 4px;margin-bottom:8px}
		.search_page .filter_box {padding-left:8px}
		.search_page .filter_box>a {font-weight:700;color:#009900}
		.search_page .filter_box ul {padding:2px 0 10px}
		.search_page .filter_box li {padding:3px 12px;line-height:1.2;font-size:12px;position:relative}
		.search_page .filter_remove {position:absolute;left:-4px;top:1px;font-family: "Helvetica Neue",Helvetica,Arial,sans-serif;color:#000;float:right;font-size:20px;font-weight:700;line-height:18px;opacity:0.2;text-shadow:0 1px 0 #FFF}
		.search_page .filter_remove:hover{color:#000;cursor:pointer;opacity:0.4;text-decoration:none}
		.search_content {border-top:1px solid #dcdcdc}
		.search_content li {display:block;position:relative;padding:10px 30px;border-bottom:1px solid #dcdcdc}
		.search_content li.search_odd {background:#f2f9ff}
		.search_content .item_title {font-size:14px;margin-bottom:10px;font-weight:700}
		.search_content .item_description {margin-bottom:10px}
		.search_content .item_tags {margin-bottom:10px;font-size:11px;color:#ddd;line-height:15px}
		.search_content .item_tags span {color:#797979}
		.search_content .item_nb {position:absolute;left:8px;top:13px;font-size:11px;color:#858585}
		.search_content .item_label {position:absolute;top:9px;right:9px}
		.search_page #sort_select {margin:8px 0 0 5px}
		.search_page .pagination_bottom li {float:none;display:inline-block}
		
/* -----------------------------------------
   Site adjustements
----------------------------------------- */

	/* cross browser inline-block display */
		.btn,.ntf_item,.ntf_tip,.user_box a,.overview_list li strong,.gallery_pagination a,
		.pricing_panel,.pricing_promoted,form label {display:-moz-inline-stack;display:inline-block;*zoom: 1;*display:inline}

	/* Font Face */
		#smoothmenu_h ul,#smoothmenu_v ul,.st-accordion .top_Ha {font-family: 'Open Sans Condensed', sans-serif;}
		h1,h2,h3,h4,h5,.box_c_heading p {font-family: 'Terminal Dosis', sans-serif;}

	/* round corners */
		.user_box,#search_box,.pricing_table .pricing_promoted,
		.gallery_pagination a,.lbl,#slide_content,.msg_box,
		.gallery_list li,.nstd_acc h4, #main_nav {-webkit-border-radius: 4px;-moz-border-radius: 4px;-ms-border-radius: 4px;border-radius: 4px}

	/* gradients */
		.slider-content .title,.stepy-titles li { background: #f9f9f9;background: -moz-linear-gradient(top,  #f9f9f9 0%, #f0f0f0 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f9f9f9), color-stop(100%,#f0f0f0));background: -webkit-linear-gradient(top,  #f9f9f9 0%,#f0f0f0 100%);background: -o-linear-gradient(top,  #f9f9f9 0%,#f0f0f0 100%);background: -ms-linear-gradient(top,  #f9f9f9 0%,#f0f0f0 100%);background: linear-gradient(top,  #f9f9f9 0%,#f0f0f0 100%);filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f9f9f9', endColorstr='#f0f0f0',GradientType=0 )}

		.grdnt_a .box_c_heading,.ssw_grdnt_a { background: #f2f2f2;background: -moz-linear-gradient(top, #f2f2f2 0%, #e5e5e5 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f2f2f2), color-stop(100%,#e5e5e5));background: -webkit-linear-gradient(top, #f2f2f2 0%,#e5e5e5 100%);background: -o-linear-gradient(top, #f2f2f2 0%,#e5e5e5 100%);background: -ms-linear-gradient(top, #f2f2f2 0%,#e5e5e5 100%);background: linear-gradient(top, #f2f2f2 0%,#e5e5e5 100%);}
		.grdnt_b .box_c_heading, .ssw_grdnt_b {background: #f6f8f9;background: -moz-linear-gradient(top,  #f6f8f9 0%, #e5ebee 50%, #d7dee3 51%, #f5f7f9 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#f6f8f9), color-stop(50%,#e5ebee), color-stop(51%,#d7dee3), color-stop(100%,#f5f7f9));background: -webkit-linear-gradient(top,  #f6f8f9 0%,#e5ebee 50%,#d7dee3 51%,#f5f7f9 100%);background: -o-linear-gradient(top,  #f6f8f9 0%,#e5ebee 50%,#d7dee3 51%,#f5f7f9 100%);background: -ms-linear-gradient(top,  #f6f8f9 0%,#e5ebee 50%,#d7dee3 51%,#f5f7f9 100%);background: linear-gradient(top,  #f6f8f9 0%,#e5ebee 50%,#d7dee3 51%,#f5f7f9 100%);filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#f6f8f9', endColorstr='#f5f7f9',GradientType=0 )}
		.grdnt_a .box_c_ico,.grdnt_b .box_c_ico {background: rgba(255,255,255,.7)}
		.grdnt_c .box_c_heading, .ssw_grdnt_c {background: #1693a5;background: -moz-linear-gradient(top, #1693a5 0%, #137b89 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#1693a5), color-stop(100%,#137b89));background: -webkit-linear-gradient(top, #1693a5 0%,#137b89 100%);background: -o-linear-gradient(top, #1693a5 0%,#137b89 100%);background: -ms-linear-gradient(top, #1693a5 0%,#137b89 100%);background: linear-gradient(top, #1693a5 0%,#137b89 100%);color:#fff}		.grdnt_c .box_c_heading,.grdnt_c .box_c_ico {border-color:#0f606b}
		.grdnt_d .box_c_heading, .ssw_grdnt_d {background:#A80000;color:#fff}
		.grdnt_d .box_c_heading,.grdnt_d .box_c_ico {border-color:#8f0000}
		.grdnt_e .box_c_heading, .ssw_grdnt_e {background: #45484d;background: -moz-linear-gradient(top, #45484d 0%, #000000 100%);background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#45484d), color-stop(100%,#000000));background: -webkit-linear-gradient(top, #45484d 0%,#000000 100%);background: -o-linear-gradient(top, #45484d 0%,#000000 100%);background: -ms-linear-gradient(top, #45484d 0%,#000000 100%);background: linear-gradient(top, #45484d 0%,#000000 100%);filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#45484d', endColorstr='#000000',GradientType=0 );color:#fff}
		.grdnt_e .box_c_heading,.grdnt_e .box_c_ico {border-color:#000}
		.grdnt_c .box_c_heading a,.grdnt_d .box_c_heading a,.grdnt_e .box_c_heading a {color:#fff}

	/* backgrounds */
		.ptrn_a {background-image: url(../img/bg_a.png)}
		.ptrn_b {background-image: url(../img/bg_b.png)}
		.ptrn_c {background-image: url(../img/bg_c.png)}
		.ptrn_d {background-image: url(../img/bg_d.png)}
		.ptrn_e {background-image: url(../img/bg_e.png)}

	/* menu hover backgrounds */
		.ssw_mhover_a {background: #eaf4f9}
		.mhover_a .ddsmoothmenu ul li a.selected,.mhover_a .ddsmoothmenu ul li a:hover,
		.mhover_a .ddsmoothmenu-v ul li a.selected,.mhover_a .ddsmoothmenu-v ul li a:hover, .mhover_a .ddsmoothmenu .pageselected {background-color: #eaf4f9}
		.ssw_mhover_b {background: #eaf9ea}
		.mhover_b .ddsmoothmenu ul li a.selected,.mhover_b .ddsmoothmenu ul li a:hover,
		.mhover_b .ddsmoothmenu-v ul li a.selected,.mhover_b .ddsmoothmenu-v ul li a:hover, .mhover_b .ddsmoothmenu .pageselected {background-color: #eaf9ea}
		.ssw_mhover_c {background: #e3f8fb}
		.mhover_c .ddsmoothmenu ul li a.selected,.mhover_c .ddsmoothmenu ul li a:hover,
		.mhover_c .ddsmoothmenu-v ul li a.selected,.mhover_c .ddsmoothmenu-v ul li a:hover, .mhover_c .ddsmoothmenu .pageselected {background-color: #e3f8fb}
		.ssw_mhover_d {background: #ffe4e4}
		.mhover_d .ddsmoothmenu ul li a.selected,.mhover_d .ddsmoothmenu ul li a:hover,
		.mhover_d .ddsmoothmenu-v ul li a.selected,.mhover_d .ddsmoothmenu-v ul li a:hover, .mhover_d .ddsmoothmenu .pageselected {background-color: #ffe4e4}
		.ssw_mhover_e {background: #444}
		.mhover_e .ddsmoothmenu ul li a.selected,.mhover_e .ddsmoothmenu ul li a:hover,
		.mhover_e .ddsmoothmenu-v ul li a.selected,.mhover_e .ddsmoothmenu-v ul li a:hover, .mhover_e .ddsmoothmenu .pageselected {background-color: #2b2b2b;color:#fff}
		.mhover_e .ddsmoothmenu > ul li a.selected,.mhover_e .ddsmoothmenu > ul li a:hover,
		.mhover_e #smoothmenu_v > ul li a.selected,.mhover_e #smoothmenu_v > ul li a:hover {border-color:#000}
		.mhover_e .ddsmoothmenu ul li a {text-shadow: none}

	/* full/fixed width */
		.fullW .container > .row {max-width:100%}


/* -----------------------------------------
   Style switcher
----------------------------------------- */

	.ssw_trigger{position:fixed;top:40px;left:-1px;z-index:1001;text-decoration: none;font-size: 12px;color:#fff;width:15px;height:15px;padding: 6px 12px 6px 6px;background:#333 url(../img/settings.png) no-repeat 50% 50%;display: block;-webkit-border-top-right-radius: 8px;-webkit-border-bottom-right-radius: 8px;-moz-border-radius-topright: 8px;-moz-border-radius-bottomright: 8px;border-top-right-radius: 8px;border-bottom-right-radius: 8px;border:1px solid transparent}
	.ssw_trigger.active {border-color:#555}
	.style_switcher {font-size:12px;z-index:1000;position:fixed;top:30px;left:0;display:none;background:#000;background: rgba(0,0,0,.8);border:1px solid #111;-moz-border-radius-topright: 12px;-webkit-border-top-right-radius: 12px;-moz-border-radius-bottomright: 12px;-webkit-border-bottom-right-radius: 12px;width: 150px;height: auto;padding: 30px 30px 30px 50px;color:#f5f5f5}
	.style_switcher p {margin:0 0 6px}
	.style_item {display:block;margin-right:6px;height:20px;width:20px;border:2px solid #fff;float:left}
	.ssw_ptrn_a {background: url(../img/ssw_patterns.png) no-repeat 0 0}
	.ssw_ptrn_b {background: url(../img/ssw_patterns.png) no-repeat -30px 0}
	.ssw_ptrn_c {background: url(../img/ssw_patterns.png) no-repeat -60px 0}
	.ssw_ptrn_d {background: url(../img/ssw_patterns.png) no-repeat -90px 0}
	.ssw_ptrn_e {background: url(../img/ssw_patterns.png) no-repeat -120px 0}
	.style_active {border-color:#6fd05b}


/* -----------------------------------------
   Media queries
----------------------------------------- */

	/* Smaller than standard 960 (devices and browsers) */
		@media only screen and (max-width: 959px) {
			.sw_width {display: none}
		}

	/* Tablet Portrait size to standard 960 (devices and browsers) */
		@media only screen and (min-width: 768px) and (max-width: 959px) {
			.user_avatar {display:none}
			.user_box .user_info {border:none !important;margin:0 !important}
			.ntf_bar {float:right;padding-left:20px}
			.user_avatar {display:none}
			.overview_list {text-align:center}
			.overview_list a {line-height:16px}
			.overview_list a span {float:none;border:none;box-shadow:none;margin:0 0 2px;padding:0;text-align:center}
		}

	/* common styles max-width 767px */
		@media only screen and (max-width: 767px) {
			#logo img {padding:10px 0 0 5px}
			.ntf_bar {float:right}
			#search_box {margin-bottom:0}
			#search_box input[type="text"] {margin-top:2px}
			.user_box {float:none;margin-top:0}
			#rightcol_content {padding-left:0}
			.columns + .columns,.column + .column {margin-top:10px}
			.row .phone-one, .row .phone-two, .row .phone-three, .row .phone-four {margin-top:0}
			.v_navi {list-style:none;width:100%;float:none;left:0;overflow:hidden;left:-1px;padding:0;top:1px}
			.v_navi li {float:left;border-width:0 1px;margin-bottom:0}
			.v_scrollable {float:none;border-top:1px solid #dcdcdc;border-left:none;padding:0;margin:0}
			.v_scrollable .page {padding: 10px 20px}
			.mobileselect {width:96%;margin:4px 2%;font-family: arial,sans-serif}
			.dataTables_length,.dataTables_filter {float:none;clear:both;width:100%;text-align:left;padding:4px 0}
			.pricing_table .pricing_panel,.pricing_table .pricing_promoted {width:auto;display:block}
			.ssw_trigger,#leftcol {display:none !important}
			.block-grid.mobile > li {margin-bottom:10px}
			.dataTables_info {float:none;margin-bottom:8px}
			.dataTables_paginate {display:block;float:none !important;text-align:left}
			.dataTables_paginate .first {margin-left:0}
            select.st-nav {max-width:240px}
            .login_box {margin-top:50px}
			#l_form .button {margin-top:10px}
            .lb_content {padding-bottom:10px}
            .lb_ribbon {display:none}
            .sl_link {margin:0 0 10px 0;float:none;clear:both}
			.form-field.error small, small.error {width:100%}
			.use-sidebar #sidebar, #sidebar {display:block;clear:both;width:100% !important;float:none}
			.use-sidebar #mainCol {margin-left:0 !important}
			.use-sidebar .divider {display: none !important}
            .tinynav { display: block;width:96%;margin: 6px auto;padding:3px 0;background: transparent url(../img/down.gif) no-repeat right center;border: none }
            #smoothmenu_h ul { display: none }
		}

	/* Mobile Landscape Size to Tablet Portrait (devices and browsers) */
		@media only screen and (min-width: 480px) and (max-width: 767px) {
			.ntf_bar {padding-left:20px}
			#search_box input[type="text"] {width:122px}
		}

	/* Mobile Portrait Size to Mobile Landscape Size (devices and browsers) */
		@media only screen and (max-width: 479px) {
            #logo img {padding:16px 0 0 5px}
			#search_box input[type="text"] {width:82px}
			.user_box {padding:10px 10px 5px;float:none;margin-top:0}
			.user_box .user_info {overflow:hidden;float:left;padding:0}
			.user_box .user_info {max-width:106px;border:none !important;margin:0 !important;padding-top:2px}
			.user_box .user_info span {display:block}
			.ntf_bar {padding-left:0;float:right}
			.user_box .user_sep {border:none}
			.box_c_ico,.user_avatar,.jqplot-point-label,.fc-header-right,.fc-button-today,#breadcrumbs {display:none}
			.tabs li a {padding:0 4px;font-size:10px}
			#rightcol_content {margin:0 !important}
            .stepy-titles li {float:none;clear:both;margin-right:0}
			.st-accordion .top_Ha {font-size:18px}
			.st-content p {font-size: 13px;padding: 0 0 10px;line-height:1.3}
			.error_box {background:#fff;padding:20px 20px 40px;margin-top:10%}
			.form_content {border-left:none}
		}